@@ -21,8 +21,10 @@ midPoint <- function(p1, p2) {
 
 	p1 <- .pointsToMatrix(p1) * toRad
 	p2 <- .pointsToMatrix(p2) * toRad
-    .compareDim(p1, p2)
-
+	p <- cbind(p1[,1], p1[,2], p2[,1], p2[,2])	
+	p1 <- p[, 1:2, drop=FALSE]
+	p2 <- p[, 3:4, drop=FALSE]
+	
 	lon1 <- p1[,1]
 	lat1 <- p1[,2]
 	lon2 <- p2[,1]
@@ -41,5 +43,6 @@ midPoint <- function(p1, p2) {
 	
 	res <- cbind(lon3, lat3) / toRad
 	colnames(res) <- c('lon', 'lat')
+	
 	return(res)
 }
