@@ -5,10 +5,9 @@
 
 
 .pointsToMatrix <- function(p) {
-	if (class(p) == 'SpatialPoints' | class(p) == 'SpatialPointsDataFrame') {
-		require(sp)
-		if (is.projected(p)) {
-			stop('data points should not be projected. Either unproject or use Euclidean distances')  
+	if (inherits(p, 'SpatialPoints')) {
+		if (isTRUE (is.projected(p)) ) {
+			stop('data points should be in degrees (longitude / latitude), and not be projected')  
 			# or rather transform them ....?
 		}
 		p <- coordinates(p)
@@ -29,21 +28,22 @@
 		cn <- colnames(p)
 		if (length(cn) == 2) {
 			if (toupper(cn[1]) == 'Y' | toupper(cn[2]) == 'X')  {
-				stop('Highly suspect column names (x and y reversed?)')
+				stop('Suspect column names (x and y reversed?)')
 			}
 			if (toupper(substr(cn[1],1,3) == 'LAT' | toupper(substr(cn[2],1,3)) == 'LON'))  {
-				stop('Highly suspect column names (longitude and latitude reversed?)')
+				stop('Suspect column names (longitude and latitude reversed?)')
 			}
 		}		
 	} else {
 		stop('points should be vectors of length 2, matrices with 2 columns, or a SpatialPoints* object')
 	}
 
-	if (min(p[,1]) < -360) { stop('longitude < -360') }
-	if (max(p[,1]) > 360) {  stop('longitude > 360')  }
-	if (min(p[,2]) < -90) {  stop('latitude < -90')  }
-	if (max(p[,2]) > 90) {  stop('latitude > 90')  }
+	if (min(p[,1], na.rm=TRUE) < -720) { stop('longitude < -720') }
+	if (max(p[,1], na.rm=TRUE) > 720) {  stop('longitude > 720')  }
+	if (min(p[,2], na.rm=TRUE) < -90) {  stop('latitude < -90')  }
+	if (max(p[,2], na.rm=TRUE) > 90) {  stop('latitude > 90')  }
 	
+	if (! is.numeric(p) ) { p[] <- as.numeric(p) }
 	return(p)
 }
 
